@@ -1,42 +1,41 @@
 """Command line interface for dvc."""
-
 from __future__ import print_function
 from __future__ import unicode_literals
 
-import sys
 import argparse
 import logging
+import sys
 
-from dvc.command.base import fix_subparsers
-import dvc.command.init as init
+import dvc.command.add as add
+import dvc.command.cache as cache
+import dvc.command.checkout as checkout
+import dvc.command.commit as commit
+import dvc.command.config as config
+import dvc.command.daemon as daemon
+import dvc.command.data_sync as data_sync
+import dvc.command.destroy as destroy
+import dvc.command.diff as diff
+import dvc.command.gc as gc
 import dvc.command.get as get
 import dvc.command.get_url as get_url
-import dvc.command.destroy as destroy
-import dvc.command.remove as remove
-import dvc.command.move as move
-import dvc.command.unprotect as unprotect
-import dvc.command.run as run
-import dvc.command.repro as repro
-import dvc.command.data_sync as data_sync
-import dvc.command.gc as gc
-import dvc.command.add as add
 import dvc.command.imp as imp
 import dvc.command.imp_url as imp_url
-import dvc.command.config as config
-import dvc.command.checkout as checkout
-import dvc.command.remote as remote
-import dvc.command.cache as cache
-import dvc.command.metrics as metrics
+import dvc.command.init as init
 import dvc.command.install as install
-import dvc.command.root as root
 import dvc.command.lock as lock
+import dvc.command.metrics as metrics
+import dvc.command.move as move
 import dvc.command.pipeline as pipeline
-import dvc.command.daemon as daemon
-import dvc.command.commit as commit
+import dvc.command.remote as remote
+import dvc.command.remove as remove
+import dvc.command.repro as repro
+import dvc.command.root as root
+import dvc.command.run as run
 import dvc.command.tag as tag
-import dvc.command.diff as diff
-import dvc.command.version as version
+import dvc.command.unprotect as unprotect
 import dvc.command.update as update
+import dvc.command.version as version
+from dvc.command.base import fix_subparsers
 from dvc.exceptions import DvcParserError
 
 
@@ -144,6 +143,19 @@ def parse_args(argv=None):
         description=desc,
         parents=[parent_parser],
         formatter_class=argparse.RawTextHelpFormatter,
+        add_help=False,
+    )
+
+    # NOTE: We are doing this to capitalize help message.
+    # Unfortunately, there is no easier and clearer way to do it,
+    # as adding this argument in get_parent_parser() either in
+    # log_level_group or on parent_parser itself will cause unexpected error.
+    parser.add_argument(
+        "-h",
+        "--help",
+        action="help",
+        default=argparse.SUPPRESS,
+        help="Show this help message and exit.",
     )
 
     # NOTE: On some python versions action='version' prints to stderr
